@@ -8,7 +8,7 @@ import pandas as pd
 
 
 class CUPSCAU(object):
-    def __init__(self, data, distributor=None, compression='bz2'):
+    def __init__(self, data, distributor=None, compression='bz2', version=0):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
@@ -18,7 +18,7 @@ class CUPSCAU(object):
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'CUPSCAU'
-        self.version = 0
+        self.version = version
         self.default_compression = compression
         self.distributor = distributor
 
